==> projen-0.27.22.tar.gz: package/lib/web/react.d.ts <==
import { Component } from '../component';
import { FileBase, FileBaseOptions, IResolver } from '../file';
import { NodeProject, NodeProjectOptions } from '../node-project';
import { TypeScriptAppProject, TypeScriptProjectOptions } from '../typescript';
/**
 * @experimental
 */
export interface ReactRewireOptions {
    /**
     * (experimental) Rewire webpack configuration.
     *
     * Use this property to override webpack configuration properties provided
     * by create-react-app, without needing to eject.
     *
     * This property will create a `config-overrides.js` file in your root directory,
     * which will contain the desired rewiring code.
     *
     * To **override** the configuration, you can provide simple key value pairs.
     * Keys take the form of js code directives that traverse to the desired property.
     * Values should be JSON serializable objects.
     *
     * For example, the following config:
     *
     * ```json
     * rewire: { "module.unknownContextCritical": false }
     * ```
     *
     * Will translate to the following `config-overrides.js` file:
     *
     * ```js
     * module.exports = function override(config, env) {
     *    config.module.unknownContextCritical = false;
     * }
     * ```
     *
     * @default - No rewired config.
     * @see https://github.com/timarney/react-app-rewired
     * @experimental
     */
    readonly rewire?: {
        [key: string]: any;
    };
}
/**
 * @experimental
 */
export interface ReactTypeScriptProjectOptions extends TypeScriptProjectOptions, ReactRewireOptions {
}
/**
 * @experimental
 */
export interface ReactProjectOptions extends NodeProjectOptions, ReactRewireOptions {
    /**
     * (experimental) Source directory.
     *
     * @default "src"
     * @experimental
     */
    readonly srcdir?: string;
    /**
     * (experimental) Generate one-time sample in `src/` and `public/` if there are no files there.
     *
     * @default true
     * @experimental
     */
    readonly sampleCode?: boolean;
}
/**
 * (experimental) React project without TypeScript.
 *
 * @experimental
 * @pjid react
 */
export declare class ReactProject extends NodeProject {
    /**
     * (experimental) The directory in which source files reside.
     *
     * @default "src"
     * @experimental
     */
    readonly srcdir: string;
    /**
     * @experimental
     */
    constructor(options: ReactProjectOptions);
}
/**
 * (experimental) React project with TypeScript.
 *
 * @experimental
 * @pjid react-ts
 */
export declare class ReactTypeScriptProject extends TypeScriptAppProject {
    /**
     * (experimental) The directory in which source files reside.
     *
     * @experimental
     */
    readonly srcdir: string;
    /**
     * (experimental) TypeScript definition file included that ensures React types are picked up by the TypeScript compiler.
     *
     * @experimental
     */
    readonly reactTypeDef: ReactTypeDef;
    /**
     * @experimental
     */
    constructor(options: ReactTypeScriptProjectOptions);
}
/**
 * @experimental
 */
export interface ReactComponentOptions extends ReactRewireOptions {
    /**
     * (experimental) Whether to apply options specific for TypeScript React projects.
     *
     * @default false
     * @experimental
     */
    readonly typescript?: boolean;
}
/**
 * @experimental
 */
export declare class ReactComponent extends Component {
    private readonly typescript;
    /**
     * @experimental
     */
    constructor(project: NodeProject, options: ReactComponentOptions);
}
/**
 * @experimental
 */
export interface ReactTypeDefOptions extends FileBaseOptions {
}
/**
 * @experimental
 */
export declare class ReactTypeDef extends FileBase {
    /**
     * @experimental
     */
    constructor(project: ReactTypeScriptProject, filePath: string, options?: ReactTypeDefOptions);
    /**
     * (experimental) Implemented by derived classes and returns the contents of the file to emit.
     *
     * @experimental
     */
    protected synthesizeContent(_: IResolver): string | undefined;
}

==> projen-0.46.3.tar.gz: package/lib/web/react.d.ts <==
import { Component } from '../component';
import { FileBase, FileBaseOptions, IResolver } from '../file';
import { NodeProject, NodeProjectOptions } from '../javascript';
import { TypeScriptAppProject, TypeScriptProjectOptions } from '../typescript';
/**
 * @experimental
 */
export interface ReactRewireOptions {
    /**
     * (experimental) Rewire webpack configuration.
     *
     * Use this property to override webpack configuration properties provided
     * by create-react-app, without needing to eject.
     *
     * This property will create a `config-overrides.js` file in your root directory,
     * which will contain the desired rewiring code.
     *
     * To **override** the configuration, you can provide simple key value pairs.
     * Keys take the form of js code directives that traverse to the desired property.
     * Values should be JSON serializable objects.
     *
     * For example, the following config:
     *
     * ```json
     * rewire: { "module.unknownContextCritical": false }
     * ```
     *
     * Will translate to the following `config-overrides.js` file:
     *
     * ```js
     * module.exports = function override(config, env) {
     *    config.module.unknownContextCritical = false;
     * }
     * ```
     *
     * @default - No rewired config.
     * @see https://github.com/timarney/react-app-rewired
     * @experimental
     */
    readonly rewire?: {
        [key: string]: any;
    };
}
/**
 * @experimental
 */
export interface ReactTypeScriptProjectOptions extends TypeScriptProjectOptions, ReactRewireOptions {
}
/**
 * @experimental
 */
export interface ReactProjectOptions extends NodeProjectOptions, ReactRewireOptions {
    /**
     * (experimental) Source directory.
     *
     * @default "src"
     * @experimental
     */
    readonly srcdir?: string;
    /**
     * (experimental) Generate one-time sample in `src/` and `public/` if there are no files there.
     *
     * @default true
     * @experimental
     */
    readonly sampleCode?: boolean;
}
/**
 * (experimental) React project without TypeScript.
 *
 * @experimental
 * @pjid react
 */
export declare class ReactProject extends NodeProject {
    /**
     * (experimental) The directory in which source files reside.
     *
     * @default "src"
     * @experimental
     */
    readonly srcdir: string;
    /**
     * @experimental
     */
    constructor(options: ReactProjectOptions);
}
/**
 * (experimental) React project with TypeScript.
 *
 * @experimental
 * @pjid react-ts
 */
export declare class ReactTypeScriptProject extends TypeScriptAppProject {
    /**
     * (experimental) The directory in which source files reside.
     *
     * @experimental
     */
    readonly srcdir: string;
    /**
     * (experimental) TypeScript definition file included that ensures React types are picked up by the TypeScript compiler.
     *
     * @experimental
     */
    readonly reactTypeDef: ReactTypeDef;
    /**
     * @experimental
     */
    constructor(options: ReactTypeScriptProjectOptions);
}
/**
 * @experimental
 */
export interface ReactComponentOptions extends ReactRewireOptions {
    /**
     * (experimental) Whether to apply options specific for TypeScript React projects.
     *
     * @default false
     * @experimental
     */
    readonly typescript?: boolean;
}
/**
 * @experimental
 */
export declare class ReactComponent extends Component {
    private readonly typescript;
    /**
     * @experimental
     */
    constructor(project: NodeProject, options: ReactComponentOptions);
}
/**
 * @experimental
 */
export interface ReactTypeDefOptions extends FileBaseOptions {
}
/**
 * @experimental
 */
export declare class ReactTypeDef extends FileBase {
    /**
     * @experimental
     */
    constructor(project: ReactTypeScriptProject, filePath: string, options?: ReactTypeDefOptions);
    /**
     * (experimental) Implemented by derived classes and returns the contents of the file to emit.
     *
     * @experimental
     */
    protected synthesizeContent(_: IResolver): string | undefined;
}
